"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const dal_configuration_1 = require("./../../../configuration/dal.configuration");
class GenericStore {
    static connect() {
        return __awaiter(this, void 0, void 0, function* () {
            const client = yield mongodb_1.MongoClient.connect(dal_configuration_1.DalConfiguration.url, {
                auth: {
                    user: dal_configuration_1.DalConfiguration.username,
                    password: dal_configuration_1.DalConfiguration.password
                },
                useNewUrlParser: true
            });
            return client;
        });
    }
    static createOrUpdate(collectionName, term, value) {
        return __awaiter(this, void 0, void 0, function* () {
            dal_configuration_1.DalConfiguration.Verify();
            const client = yield this.connect();
            try {
                let db = client.db(dal_configuration_1.DalConfiguration.database);
                let collection = db.collection(collectionName);
                let result = yield collection.findOneAndUpdate(term, { $set: value }, { upsert: true });
                if (result.ok === 1)
                    return true;
                else
                    return false;
            }
            finally {
                yield client.close();
            }
        });
    }
    static clearAndCreateMany(collectionName, term, values) {
        return __awaiter(this, void 0, void 0, function* () {
            dal_configuration_1.DalConfiguration.Verify();
            const client = yield this.connect();
            try {
                let db = client.db(dal_configuration_1.DalConfiguration.database);
                let collection = db.collection(collectionName);
                let deleteResult = yield collection.deleteMany(term);
                let insertResult = yield collection.insertMany(values);
                if (deleteResult.result.ok === 1 && insertResult.result.ok === 1) {
                    return true;
                }
                else {
                    return false;
                }
            }
            finally {
                yield client.close();
            }
        });
    }
    static clearAllAndCreateMany(collectionName, values) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield GenericStore.clearAndCreateMany(collectionName, {}, values);
        });
    }
    static getAll(collectionName) {
        return __awaiter(this, void 0, void 0, function* () {
            dal_configuration_1.DalConfiguration.Verify();
            const client = yield this.connect();
            try {
                let db = client.db(dal_configuration_1.DalConfiguration.database);
                let collection = db.collection(collectionName);
                const result = yield collection.find().toArray();
                return result;
            }
            finally {
                yield client.close();
            }
        });
    }
    static getBy(collectionName, term, sort) {
        return __awaiter(this, void 0, void 0, function* () {
            dal_configuration_1.DalConfiguration.Verify();
            const client = yield this.connect();
            try {
                let db = client.db(dal_configuration_1.DalConfiguration.database);
                let collection = db.collection(collectionName);
                const result = yield collection
                    .find(term)
                    .sort(sort)
                    .toArray();
                return result;
            }
            finally {
                yield client.close();
            }
        });
    }
    static remove(collectionName, term) {
        return __awaiter(this, void 0, void 0, function* () {
            dal_configuration_1.DalConfiguration.Verify();
            const client = yield this.connect();
            try {
                let db = client.db(dal_configuration_1.DalConfiguration.database);
                let collection = db.collection(collectionName);
                let result = yield collection.deleteOne(term);
                return result.deletedCount === 1;
            }
            finally {
                yield client.close();
            }
        });
    }
}
exports.GenericStore = GenericStore;
//# sourceMappingURL=dal.generic.store.js.map